@@ -1,6 +1,6 @@
 package Net::Kubernetes;
 # ABSTRACT: An object oriented interface to the REST API's provided by kubernetes
-$Net::Kubernetes::VERSION = '0.13';
+$Net::Kubernetes::VERSION = '0.14';
 use Moose;
 require Net::Kubernetes::Namespace;
 require LWP::UserAgent;
@@ -43,6 +43,36 @@ sub get_namespace {
 	}
 }
 
+
+sub list_nodes {
+	my $self = shift;
+	my(%options);
+	if (ref($_[0])) {
+		%options = %{ $_[0] };
+	}else{
+		%options = @_;
+	}
+
+	my $uri = URI->new($self->path.'/nodes');
+	my(%form) = ();
+	$form{labelSelector}=$self->_build_selector_from_hash($options{labels}) if (exists $options{labels});
+	$form{fieldSelector}=$self->_build_selector_from_hash($options{fields}) if (exists $options{fields});
+	$uri->query_form(%form);
+
+	my $res = $self->ua->request($self->create_request(GET => $uri));
+	if ($res->is_success) {
+		my $event_list = $self->json->decode($res->content);
+		my(@events)=();
+		foreach my $service (@{ $event_list->{items}}){
+			$service->{apiVersion} = $event_list->{apiVersion};
+			push @events, $self->create_resource_object($service, 'Node');
+		}
+		return wantarray ? @events : \@events;
+	}else{
+		Net::Kubernetes::Exception->throw(code=>$res->code, message=>$res->message);
+	}
+}
+
 sub _get_default_namespace {
 	my($self) = @_;
 	return $self->get_namespace('default');
@@ -64,7 +94,7 @@ Net::Kubernetes - An object oriented interface to the REST API's provided by kub
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -138,11 +168,15 @@ Delegates automatically to L<Net::Kubernetes::Namespace> via $self->get_namespac
 
 Delegates automatically to L<Net::Kubernetes::Namespace> via $self->get_namespace('default')
 
+=head2 list_nodes([label=>{label=>value}], [fields=>{field=>value}])
+
+returns a list of L<Net::Kubernetes::Resource::Node>s
+
 =begin html
 
 <h2>Build Status</h2>
 
-<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=release-0.13" />
+<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=release-0.14" />
 
 =end html
 
