@@ -1,6 +1,6 @@
 package Net::Kubernetes::Role::ResourceFactory;
 # ABSTRACT: Role to allow easy construction of Net::Kubernetes::Resouce::* objects
-$Net::Kubernetes::Role::ResourceFactory::VERSION = '0.13';
+$Net::Kubernetes::Role::ResourceFactory::VERSION = '0.14';
 use Moose::Role;
 use MooseX::Aliases;
 require Net::Kubernetes::Resource::Service;
@@ -8,6 +8,8 @@ require Net::Kubernetes::Resource::Pod;
 require Net::Kubernetes::Resource::ReplicationController;
 require Net::Kubernetes::Resource::Secret;
 require Net::Kubernetes::Resource::Event;
+require Net::Kubernetes::Resource::Node;
+require Net::Kubernetes::Resource::Endpoint;
 
 sub create_resource_object {
 	my($self, $object, $kind) = @_;
@@ -37,7 +39,7 @@ Net::Kubernetes::Role::ResourceFactory - Role to allow easy construction of Net:
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 AUTHOR
 
