@@ -1,6 +1,6 @@
 package Net::Kubernetes::Role::ResourceLister;
 # ABSTRACT: Role to give access to list_* methods.
-$Net::Kubernetes::Role::ResourceLister::VERSION = '0.13';
+$Net::Kubernetes::Role::ResourceLister::VERSION = '0.14';
 use Moose::Role;
 use MooseX::Aliases;
 require Net::Kubernetes::Resource::Service;
@@ -165,6 +165,36 @@ sub list_secrets {
 	}
 }
 
+
+sub list_endpoints {
+	my $self = shift;
+	my(%options);
+	if (ref($_[0])) {
+		%options = %{ $_[0] };
+	}else{
+		%options = @_;
+	}
+
+	my $uri = URI->new($self->path.'/enpoints');
+	my(%form) = ();
+	$form{labelSelector}=$self->_build_selector_from_hash($options{labels}) if (exists $options{labels});
+	$form{fieldSelector}=$self->_build_selector_from_hash($options{fields}) if (exists $options{fields});
+	$uri->query_form(%form);
+
+	my $res = $self->ua->request($self->create_request(GET => $uri));
+	if ($res->is_success) {
+		my $point_list = $self->json->decode($res->content);
+		my(@points)=();
+		foreach my $point (@{ $point_list->{items} }){
+			$point->{apiVersion} = $point_list->{apiVersion};
+			push @points, $self->create_resource_object($point, 'Endpoint');
+		}
+		return wantarray ? @points : \@points;
+	}else{
+		Net::Kubernetes::Exception->throw(code=>$res->code, message=>$res->message);
+	}
+}
+
 sub _build_selector_from_hash {
 	my($self, $select_hash) = @_;
 	my(@selectors);
@@ -188,7 +218,7 @@ Net::Kubernetes::Role::ResourceLister - Role to give access to list_* methods.
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 METHODS
 
@@ -210,12 +240,16 @@ returns a list of L<Net::Kubernetes::Resource::Service>s
 
 =head2 list_events([label=>{label=>value}], [fields=>{field=>value}])
 
-returns a list of L<Net::Kubernetes::Resource::Service>s
+returns a list of L<Net::Kubernetes::Resource::Event>s
 
 =head2 list_secrets([label=>{label=>value}], [fields=>{field=>value}])
 
 returns a list of L<Net::Kubernetes::Resource::Secret>s
 
+=head2 list_endpoints([label=>{label=>value}], [fields=>{field=>value}])
+
+returns a list of L<Net::Kubernetes::Resource::Endpoint>s
+
 =head1 AUTHOR
 
 Dave Mueller <dave@perljedi.com>
